@@ -183,35 +183,37 @@ class LogicalDisk(object):
                         config=self._logical_disk, reason=reason)
                 specified_disks.append(disk)
 
-            solution = self.raid_setting.get_best_matched_disks(
-                self.capacity_bytes, specified_disks, len(specified_disks))
-            if solution:
-                self.span_number = solution.span
-                for disk in solution.disks:
-                    disk.mark_as_exclusive()
-                    self.drives.append(disk.drive_id)
-            else:
-                reason = ('The specified physical disks do not have enough '
-                          'space to create a %dG logical-disk(raid-level %s).'
-                          % (self._size_gb, self.raid_setting.key))
+            try:
+                solution = self.raid_setting.get_best_matched_disks(
+                    self.capacity_bytes, specified_disks, len(specified_disks))
+                if solution:
+                    self.span_number = solution.span
+                    for disk in solution.disks:
+                        disk.mark_as_exclusive()
+                        self.drives.append(disk.drive_id)
+                else:
+                    raise exceptions.SpecifiedDisksHasNotEnoughSpace(
+                        size=self._size_gb, raid=self.raid_setting.key)
+            except exceptions.IBMCClientError as e:
                 raise exceptions.InvalidLogicalDiskConfig(
-                    config=self._logical_disk, reason=reason)
+                    config=self._logical_disk, reason=str(e))
 
         # non-share and auto choose disks (2 cases, both size int and max)
         elif not self.share_physical_disks and not self.use_specified_disks:
-            solution = self.raid_setting.get_best_matched_disks(
-                self.capacity_bytes, excludable_disks,
-                self.number_of_physical_disks)
-            if solution:
-                self.span_number = solution.span
-                for disk in solution.disks:
-                    disk.mark_as_exclusive()
-                    self.drives.append(disk.drive_id)
-            else:
-                reason = ('There are not enough available disk space to create'
-                          ' this logical disk.')
+            try:
+                solution = self.raid_setting.get_best_matched_disks(
+                    self.capacity_bytes, excludable_disks,
+                    self.number_of_physical_disks)
+                if solution:
+                    self.span_number = solution.span
+                    for disk in solution.disks:
+                        disk.mark_as_exclusive()
+                        self.drives.append(disk.drive_id)
+                else:
+                    raise exceptions.LackOfDiskSpace()
+            except exceptions.IBMCClientError as e:
                 raise exceptions.InvalidLogicalDiskConfig(
-                    config=self._logical_disk, reason=reason)
+                    config=self._logical_disk, reason=str(e))
 
         # share and use specified disks (2 cases, both size int and max)
         elif self.share_physical_disks and self.use_specified_disks:
@@ -235,15 +237,16 @@ class LogicalDisk(object):
                     raise exceptions.InvalidLogicalDiskConfig(
                         config=self._logical_disk, reason=reason)
 
-            solution = self.raid_setting.get_best_matched_disks(
-                self.capacity_bytes, specified_disks, len(specified_disks))
-            if solution:
-                self.use_shareable_solution(solution, physical_disk_groups)
-            else:
-                reason = ('There are not enough available disk space to create'
-                          ' this logical disk.')
+            try:
+                solution = self.raid_setting.get_best_matched_disks(
+                    self.capacity_bytes, specified_disks, len(specified_disks))
+                if solution:
+                    self.use_shareable_solution(solution, physical_disk_groups)
+                else:
+                    raise exceptions.LackOfDiskSpace()
+            except exceptions.IBMCClientError as e:
                 raise exceptions.InvalidLogicalDiskConfig(
-                    config=self._logical_disk, reason=reason)
+                    config=self._logical_disk, reason=str(e))
 
         elif self.share_physical_disks and not self.use_specified_disks:
             # if any exists disk group matches, we would not compare it with
@@ -256,16 +259,17 @@ class LogicalDisk(object):
                 self.use_shareable_disk_group = True
                 return
 
-            solution = self.raid_setting.get_best_matched_disks(
-                self.capacity_bytes, excludable_disks,
-                self.number_of_physical_disks)
-            if solution:
-                self.use_shareable_solution(solution, physical_disk_groups)
-            else:
-                reason = ('There are not enough available disk space to '
-                          'create this logical disk.')
+            try:
+                solution = self.raid_setting.get_best_matched_disks(
+                    self.capacity_bytes, excludable_disks,
+                    self.number_of_physical_disks)
+                if solution:
+                    self.use_shareable_solution(solution, physical_disk_groups)
+                else:
+                    raise exceptions.LackOfDiskSpace()
+            except exceptions.IBMCClientError as e:
                 raise exceptions.InvalidLogicalDiskConfig(
-                    config=self._logical_disk, reason=reason)
+                    config=self._logical_disk, reason=str(e))
 
     def use_shareable_solution(
             self,
@@ -367,7 +371,7 @@ class LogicalDisk(object):
         disk.hint = disk_hint
         return disk
 
-    def guess_span_number(self):
+    def guess_span_number(self):  # pragma: no cover
         """(deprecated) guess span number
         """
         if self.raid_setting.name in [raid_utils.RAID0, raid_utils.RAID1,
@@ -431,9 +435,9 @@ def sort_and_group_pending_logical_disk_list(logical_disks):
         if logical_disk1.capacity_bytes != logical_disk2.capacity_bytes:
             return logical_disk1.capacity_bytes - logical_disk2.capacity_bytes
 
-        return 0
+        return 0  # pragma: no cover
 
-    if six.PY2:
+    if six.PY2:  # pragma: no cover
         _logical_disk_list = sorted(
             logical_disks, cmp=compare_pending_logical_disks, reverse=True)
     elif six.PY3:
@@ -502,6 +506,10 @@ class IBMCStorageClient(BaseApiClient):
         :return:
         """
         LOG.info("Start delete all RAID configuration.")
+
+        # waiting until storage ready
+        self.waiting_storage_ready()
+
         storage_collection = self.list()
         for storage in storage_collection:
             if not storage.support_oob:
@@ -567,6 +575,10 @@ class IBMCStorageClient(BaseApiClient):
         """
         LOG.info('Start apply RAID configuration:: %(logical_disks)s',
                  {'logical_disks': logical_disks})
+
+        # waiting until storage ready
+        self.waiting_storage_ready()
+
         # load all controllers
         controllers = self.list()
 
@@ -695,6 +707,22 @@ class IBMCStorageClient(BaseApiClient):
                     **pending_volume.to_create_volume_payload())
                 time.sleep(constants.RAID_TASK_EFFECT_SECONDS)
 
+    def waiting_storage_ready(self):
+        # waiting util storage ready
+        LOG.info('Waiting until storage ready.')
+        while True:
+            system = self.ibmc_client.system.get()
+            try:
+                if system.is_storage_ready:
+                    LOG.info('Storage is ready.')
+                    break
+                LOG.info('Storage is not ready. waiting...')
+            except exceptions.FeatureNotSupported:
+                LOG.info('Query `IsStorageReady` feature is not supported, '
+                         'will treat it as ready now.')
+                break
+            time.sleep(30)
+
     @staticmethod
     def validate_pending_volumes(groups):
         for (ctrl_id, volumes) in groups.items():
