@@ -297,7 +297,7 @@ class PhysicalDiskGroup(object):
         if self.left_capacity_bytes < other.left_capacity_bytes:
             return False
 
-        return False
+        return False  # pragma: no cover
 
     def log(self, find):
         fmt_kwargs = {'disk_group': str(self),
@@ -309,7 +309,7 @@ class PhysicalDiskGroup(object):
             LOG.info('Not a better choice:: disk-group->%(disk_group)s, '
                      'left-capacity-bytes: %(left)d', fmt_kwargs)
 
-    def __repr__(self):
+    def __repr__(self):  # pragma: no cover
         return str(self)
 
     def __str__(self):
@@ -376,9 +376,9 @@ class RaidSolution(object):
         if self.disks_total_bytes > other.disks_total_bytes:
             return False
 
-        if self.disks_count < other.disks_count:
+        if self.disks_count < other.disks_count:  # pragma: no cover
             return True
-        if self.disks_count > other.disks_count:
+        if self.disks_count > other.disks_count:  # pragma: no cover
             return False
 
         return False
@@ -518,7 +518,7 @@ class Raid(object):
         :return:
         """
 
-        if self.name == JBOD:
+        if self.name == JBOD:  # pragma: no cover
             return None
 
         LOG.info('Calculate waste least disks for volume(%(raid_level)s) with'
@@ -535,11 +535,33 @@ class Raid(object):
         LOG.info('Group available disks by media type: %(disks)s',
                  {'disks': str(grouped_by_media_type)})
 
+        is_specified_disk_count_legal = disk_count_to_use is None
         best_solution = None
         for (media_type, disks_by_media_type) in grouped_by_media_type.items():
             LOG.info('Try to calculate for media type `%(media_type)s` now.',
                      {'media_type': media_type})
             for span in available_span_list:
+                if disk_count_to_use:
+                    if disk_count_to_use % span != 0:
+                        LOG.info(
+                            'Specified disk count number `%(disk_count)d` does'
+                            ' not match span number %(span)d, continue.',
+                            {'span': span, 'disk_count': disk_count_to_use})
+                        continue
+
+                    disk_count_to_use_per_span = disk_count_to_use / span
+                    if (disk_count_to_use_per_span < raid.min_disks or
+                            disk_count_to_use_per_span > raid.max_disks):
+                        LOG.info(
+                            'Specified disk count number `%(disk_count)d` '
+                            'does not match raid-level %(raid)s with '
+                            'span %(span)d, continue.',
+                            {'span': span, 'disk_count': disk_count_to_use,
+                             'raid': self.key})
+                        continue
+
+                    is_specified_disk_count_legal = True
+
                 min_disks = (disk_count_to_use if disk_count_to_use else
                              raid.min_disks * span)
                 max_disks = (disk_count_to_use if disk_count_to_use else
@@ -561,7 +583,7 @@ class Raid(object):
                              'disk_count)d.',
                              {'span': span, 'disk_count': required_disk_count})
 
-                    if required_disk_count % span != 0:
+                    if required_disk_count % span != 0:  # pragma: no cover
                         LOG.info(
                             'Disk count %(disk_count)d does not match span '
                             'number %(span)d, continue.',
@@ -605,6 +627,10 @@ class Raid(object):
                             and target_capacity > 0):
                         break
 
+        if not is_specified_disk_count_legal:
+            raise exceptions.InvalidPhysicalDiskNumber(
+                number_of_physical_disks=disk_count_to_use, raid=self.key)
+
         return best_solution
 
 
